@@ -1297,6 +1297,13 @@ class ConfigParser(RawConfigParser):
         super(ConfigParser, self).add_section(section)
 
 
+class ConfigParserCaseSens(ConfigParser):
+    u"""ConfigParser with case sensitivity keys"""
+
+    def optionxform(self, optionstr):
+        return optionstr
+
+
 class SafeConfigParser(ConfigParser):
     u"""ConfigParser alias for backwards compatibility purposes."""
 
